import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Wavefront Cloud Integration for New Relic. This allows New Relic cloud integrations to be created,
 * updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const newrelic = new wavefront.CloudIntegrationNewRelic("newrelic", {
 *     name: "Test Integration",
 *     apiKey: "example-api-key",
 * });
 * ```
 *
 * ## Import
 *
 * NewRelic Integrations can be imported by using the `id`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/cloudIntegrationNewRelic:CloudIntegrationNewRelic newrelic a411c16b-3cf7-4f03-bf11-8ca05aab898d
 * ```
 */
export declare class CloudIntegrationNewRelic extends pulumi.CustomResource {
    /**
     * Get an existing CloudIntegrationNewRelic resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudIntegrationNewRelicState, opts?: pulumi.CustomResourceOptions): CloudIntegrationNewRelic;
    /**
     * Returns true if the given object is an instance of CloudIntegrationNewRelic.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudIntegrationNewRelic;
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    readonly additionalTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * New Relic REST API key.
     */
    readonly apiKey: pulumi.Output<string>;
    /**
     * A regular expression that an application name must match (case-insensitively) in order to collect metrics.
     */
    readonly appFilterRegex: pulumi.Output<string | undefined>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    readonly forceSave: pulumi.Output<boolean | undefined>;
    /**
     * A regular expression that a host name must match (case-insensitively) in order to collect metrics.
     */
    readonly hostFilterRegex: pulumi.Output<string | undefined>;
    /**
     * See Metric Filter.
     */
    readonly metricFilters: pulumi.Output<outputs.CloudIntegrationNewRelicMetricFilter[] | undefined>;
    /**
     * The human-readable name of this integration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    readonly service: pulumi.Output<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    readonly serviceRefreshRateInMinutes: pulumi.Output<number | undefined>;
    /**
     * Create a CloudIntegrationNewRelic resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudIntegrationNewRelicArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudIntegrationNewRelic resources.
 */
export interface CloudIntegrationNewRelicState {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * New Relic REST API key.
     */
    apiKey?: pulumi.Input<string>;
    /**
     * A regular expression that an application name must match (case-insensitively) in order to collect metrics.
     */
    appFilterRegex?: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * A regular expression that a host name must match (case-insensitively) in order to collect metrics.
     */
    hostFilterRegex?: pulumi.Input<string>;
    /**
     * See Metric Filter.
     */
    metricFilters?: pulumi.Input<pulumi.Input<inputs.CloudIntegrationNewRelicMetricFilter>[]>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service?: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a CloudIntegrationNewRelic resource.
 */
export interface CloudIntegrationNewRelicArgs {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * New Relic REST API key.
     */
    apiKey: pulumi.Input<string>;
    /**
     * A regular expression that an application name must match (case-insensitively) in order to collect metrics.
     */
    appFilterRegex?: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * A regular expression that a host name must match (case-insensitively) in order to collect metrics.
     */
    hostFilterRegex?: pulumi.Input<string>;
    /**
     * See Metric Filter.
     */
    metricFilters?: pulumi.Input<pulumi.Input<inputs.CloudIntegrationNewRelicMetricFilter>[]>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
}
